@@ -11,6 +11,7 @@ import logging
 import uuid
 from collections import namedtuple
 from queue import Queue
+from threading import Lock
 from typing import Any
 
 from .compat import OK
@@ -96,7 +97,9 @@ class TelemetryEvent(TelemetryEventBase):
         event.update(
             {
                 "UUID": str(uuid.uuid4()),
-                "Created_On": datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S"),
+                "Created_On": datetime.datetime.now(datetime.timezone.utc)
+                .replace(tzinfo=None)
+                .strftime("%Y-%m-%d %H:%M:%S"),
                 "Type": self.get_type(),
                 "SchemaVersion": 1,
             }
@@ -152,13 +155,16 @@ class TelemetryMetricEvent(TelemetryEvent):
 
 class TelemetryService:
     __instance = None
+    # prevents race condition from multiple threads creating Snowflake connections
+    __lock_init = Lock()
 
-    @staticmethod
-    def get_instance() -> TelemetryService:
+    @classmethod
+    def get_instance(cls) -> TelemetryService:
         """Static access method."""
-        if TelemetryService.__instance is None:
-            TelemetryService()
-        return TelemetryService.__instance
+        with cls.__lock_init:
+            if cls.__instance is None:
+                cls()
+        return cls.__instance
 
     def __init__(self) -> None:
         """Virtually private constructor."""
